/*
 * Copyright (c) 2009 ICM Uniwersytet Warszawski All rights reserved.
 * See LICENCE file for licencing information.
 *
 * Created on 2010-02-28
 * Author: K. Benedyczak <golbi@mat.umk.pl>
 */

package pl.edu.icm.uvos.webauth;

import javax.servlet.ServletContext;

import org.apache.log4j.Logger;
import org.picocontainer.PicoContainer;

import eu.unicore.util.Log;

import pl.edu.icm.unicore.uvos.engine.InternalAuthorization;
import pl.edu.icm.unicore.uvos.server.JettyServer;
import pl.edu.icm.unicore.uvos.server.saml.SAMLAuthImpl;

/**
 * Obtains references to the UVOS server components.
 * @author golbi
 */
public class UVOSConnector
{
	private static final Logger log = Log.getLogger("unicore.uvos.webauthn", UVOSConnector.class);
	
	private InternalAuthorization authz;
	private SAMLAuthImpl samlAuthn;
	
	public UVOSConnector(ServletContext servletContext)
	{
		PicoContainer pico = (PicoContainer) servletContext.getAttribute(
			JettyServer.UVOS_SERVER_CONTAINER_REFERENCE);
		if (pico == null)
		{
			log.fatal("Can't get PicoContainer from the servlet context. Either" +
					" you deployed this servlet to an other than UVOS container " +
					" or to UVOS server with version < 1.6.0");
			throw new IllegalStateException("Can't get PicoContainer from the servlet context.");
		}
		authz = pico.getComponent(InternalAuthorization.class);
		samlAuthn = pico.getComponent(SAMLAuthImpl.class);
	}
	
	public InternalAuthorization getAuthzModule()
	{
		return authz;
	}

	public SAMLAuthImpl getSamlAuthn()
	{
		return samlAuthn;
	}
}
